import React, { useState } from "react";

import "./filtermenu.css";
import Label from "./label";
import { NodeType } from "../../../common/graph/nodetype";

interface FilterMenuProps {
    classes: Map<number, NodeType>;
    onVisibilityChange?: (visibility: Map<number, boolean>) => void;
}

/**
 * Displays a menu which can be used to filter nodes by type.
 * @param classes Map of available node classes with associated colors.
 * @param onVisibilityChange Optional handler for visibility changes.
 * @constructor
 */
function FilterMenu({ classes, onVisibilityChange }: FilterMenuProps) {
    const classList = [...classes.values()];
    const chars = Math.max(
        ...classList.map((cls) => {
            return cls.name.length;
        })
    );
    const [visibility, setVisibility] = useState(
        new Array(classList.length).fill(true)
    );

    const handleClick = (idx: number) => {
        const vis = [...visibility];
        vis[idx] = !vis[idx];
        setVisibility(vis);
        if (onVisibilityChange !== undefined) {
            onVisibilityChange(
                new Map<number, boolean>(
                    classList.map((cls, idx) => [cls.id, vis[idx]])
                )
            );
        }
    };

    const labelWidth = 10 * chars;
    const width = Math.ceil(classList.length / 3) * (labelWidth + 20);

    return (
        <div className={"filter-menu"} style={{ width }}>
            {classList.map((cls, idx) => (
                <Label
                    key={cls.id}
                    text={cls.name}
                    color={cls.color}
                    width={labelWidth}
                    active={visibility[idx]}
                    onClick={() => handleClick(idx)}
                />
            ))}
        </div>
    );
}

export default FilterMenu;
